/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.extension.controlcenter;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.af3.platform.raspberry.generator.extension.library.PiHALLibraryGeneratorExtensionBase;
import org.fortiss.af3.platform.raspberry.generator.framework.ISingletonInitializationGeneratorExtension;
import org.fortiss.af3.platform.raspberry.generator.framework.ISingletonTerminationGeneratorExtension;

/**
 * Base class for all executables of the controlcenter .
 * 
 * @author duenhuber
 */
abstract class ControlcenterGeneratorExtensionBase<T extends EObject> extends
		PiHALLibraryGeneratorExtensionBase<T> implements
		ISingletonInitializationGeneratorExtension, ISingletonTerminationGeneratorExtension {
	/** Constructor. */
	public ControlcenterGeneratorExtensionBase(T modelElement) {
		super(modelElement);
	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonVariableDeclarationCode(String singletonPostfix) {
		// return "static gamepad_configuration_t* gamepad_config_" + singletonPostfix + ";\n";
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonAuxiliaryFunctions(String singletonPostfix) {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonInitializationCode(String singletonPostfix) {
		// String prefixedVar = "gamepad_config_" + singletonPostfix;
		StringBuilder sb = new StringBuilder();
		sb.append("// initialize the control center configuration\n");
		sb.append("af3_cc_activate(\"192.168.178.99\",9999);\n\n");
		return sb.toString();

	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonTerminationCode(String singletonPrefix) {
		return "af3_cc_deactivate();\n";
	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonIdentifier() {
		// use header file as singleton identifier
		return getHeaderFileName();
	}

	/** {@inheritDoc} */
	@Override
	public final String getHeaderFileName() {
		return "controlcenter.h";
	}
}
