/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.framework;

import org.fortiss.af3.component.model.OutputPort;

/**
 * Executable for platform elements that can be written (e.g. actuators and busses). Each method
 * is provided a value by the calling code generator, which should be used to obtain the
 * value to be written. Implementors are also provided a {@code postfix} and a
 * {@code singletonPostfix} if they also implement {@link IInstanceGeneratorExtension} and
 * {@link ISingletonGeneratorExtension}, respectively. The code generator also provides the deployed
 * {@link OutputPort} in case an implementor needs additional data from the model (e.g. the type of
 * the output port).
 * 
 * @author hoelzl
 */
public interface IWriteableGeneratorExtension {
	/** Returns the write code for the given port. */
	String getWriteCode(String postfix, String singletonPostfix, OutputPort logicalSignal,
			String value);

	/**
	 * Returns the write code for the given port if the value to be written is NoVal. May return
	 * {@code null}, to indicate that NoVal is not supported.
	 */
	String getNoValWriteCode(String postfix, String singletonPostfix, OutputPort logicalSignal);
}
